% canonical bond example
clear all
close all
addpath('data')
addpath('functions')


% ---------
%  option example graph
% -------------

mu = 0.08;
sigma = 0.18; 

x = 0:0.01:3;
y = pdf('norm',x,1+mu,sigma);
y = y/(sum(y)*0.01);
shift = 6;
y2 = y(shift:end);
x2 = x(1:end-shift+1);
indx = min(find(x2>0.8));
y2(1:indx) = 0; 
y2 = y2/(sum(y2)*0.01);
meany2 = sum(x2.*y2) % check close to 108
meany = sum(x.*y)

figure
plot(x,y,'linewidth',2);
hold on
plot(x2,y2,'-r','linewidth',2);
axis([0.4 1.8 0 2.6]); 
legend('Market Index','With Protective Put')
xlabel('1 year gross return');
ylabel('probability');
set(gca,'ytick',[]')
title('Probability distribution with and without protective put')
text(1.4,1,'Lose some gains','color','r');
text(0.45,0.7,'Eliminate extreme' ,'color','r');
text(0.45,0.6,'losses' ,'color','r');

print -depsc2 protputdist.eps






% --------------
% SP500 graph
% --------------

x = load('sp500.csv');% this is the ishares sp with dividends
T = size(x,1);
mo = x(T:-1:1,1);
dy = x(T:-1:1,2);
yr = x(T:-1:1,3); 
sp = x(T:-1:1,9);

stind = find((yr == 2007)&(mo == 1)&(dy==3));
sp = sp/sp(stind);


indx = find((yr == 2008)&(mo == 12)&(dy==1));
figure
plot(datenum(yr(1:indx),mo(1:indx),dy(1:indx)),100*log(sp(1:indx)),'linewidth',1.5);
text(datenum(yr(indx),mo(indx),dy(indx)+10),100*log(sp(indx)),'What to do???')
axis([datenum(2007,1,1) datenum(2010,1,1) -inf inf])
datetick('x','keeplimits');
ylabel('Log scale -- percent')
%title('S&P500');
print -depsc2 sp5001.eps;


indx = find((yr == 2008)&(mo == 12)&(dy==1));
figure
plot(datenum(yr(1:indx),mo(1:indx),dy(1:indx)),100*log(sp(1:indx)),'linewidth',1.5);
hold on
plot(datenum(yr(indx:end),mo((indx:end)),dy((indx:end))),100*log(sp((indx:end))),'-r');
axis([datenum(2007,1,1) datenum(2010,1,1) -inf inf])
datetick('x','keeplimits');
ylabel('log scale -- percent')
title('S&P500');
print -depsc2 sp5002.eps;


x = load('vix.csv');
Tv = size(x,1);
mov = x(T:-1:1,1);
dyv = x(T:-1:1,2);
yrv = x(T:-1:1,3); 
vix = x(T:-1:1,9);

spvol = [NaN; filter(ones(20,1),1,(log(sp(2:T))-log(sp(1:T-1))).^2)];
spvol = 365*spvol.^0.5;

figure;
plot(datenum(yr(1:indx),mo(1:indx),dy(1:indx)),spvol(1:indx),'linewidth',1.5);
hold on;
plot(datenum(yrv(1:indx),mov(1:indx),dyv(1:indx)),vix(1:indx),'-c','linewidth',1.5);
text(datenum(yr(indx),mo(indx),dy(indx)+10),spvol(indx),'What to do??');
legend('Realized Volatility','VIX',2)
axis([datenum(2007,1,1) datenum(2010,1,1) -inf inf])
datetick('x','keeplimits');
ylabel('Percent')
%title('S&P500 volatility');
print -depsc2 vix5001.eps;


figure;
plot(datenum(yr(1:indx),mo(1:indx),dy(1:indx)),spvol(1:indx),'linewidth',1.5);
hold on;
plot(datenum(yrv(1:indx),mov(1:indx),dyv(1:indx)),vix(1:indx),'-c','linewidth',1.5);
plot(datenum(yr(indx:end),mo(indx:end),dy(indx:end)),spvol(indx:end),'-r');
plot(datenum(yrv(indx:end),mov(indx:end),dyv(indx:end)),vix(indx:end),'-m');
legend('montly vol.','vix',2)
axis([datenum(2007,1,1) datenum(2010,1,1) -inf inf])
datetick('x','keeplimits');
ylabel('Percent')
title('S&P500 volatility');
print -depsc2 vix5002.eps;


%Date,Open,High,Low,Close,Volume,Adj Close
%9,25,2009,105.11,105.7,104.43,104.86,4080900,104.86


% --------------------
% bond graph
% --------------------

randn('state',14);
T = 120; % horizon in months
T1 = 33; % date to consider
et = 0.0075/12*randn(T,1);
e2t = 0.000 + 10*et;
mur = 0.04/12;
rho = 0.98;
r(1) =  mur; 
for t=2:24;
    r(t)=(1-rho)*mur + rho*r(t-1)+ et(t);
end;
for t=25:36;
    r(t)=(1-rho)*mur + rho*r(t-1)+ e2t(t);
end;
for t=37:T;
    r(t)=(1-rho)*mur + rho*r(t-1)+ et(t);
end;

et_extra = [et(1:T1)*ones(1,4); 0.0075/12*randn(T-T1,4)];
e2t_extra = 0.000 + 10*et_extra;
r_extra(1,:) =  mur*ones(1,4); 
for t=2:24;
    r_extra(t,:)=(1-rho)*mur*ones(1,4) + rho*r_extra(t-1,:)+ et_extra(t,:);
end;
for t=25:36;
    r_extra(t,:)=(1-rho)*mur*ones(1,4) + rho*r_extra(t-1,:)+ e2t_extra(t,:);
end;
for t=37:T;
    r_extra(t,:)=(1-rho)*mur*ones(1,4) + rho*r_extra(t-1,:)+ et_extra(t,:);
end;


% single factor model. 

% f(n) = mu + rho^(n-1)*(r-mu)
% p(n) = -(f(1)+..+f(n)) = -[n*mu + (1-rho^n)/(1-rho)*(r-mu)]

for t = 1:T;
    n = (T-t);
    p(t) = -( n*mur + (1-rho^n)/(1-rho)*(r(t)-mur)); % this is the price of bond that maturs at T
    p_extra(t,:) = -( n*mur + (1-rho^n)/(1-rho)*(r_extra(t,:)-mur));
end;

figure
fill([2 2 3 3]',[0 105 105 0],'y');
hold on
plot((1:T1)/12,100*exp(p(1:T1)),'-v','markersize',2,'linewidth',2)
text(T1/12+.1,100*exp(p(T1)),'What to do???')
%plot((1:T)/12,1000*r,'-r')
xlabel('time, years')
ylabel('price')
title('Price of a bond that matures in year 10 -- simulation')
axis([0 10.1 0 105]);
print -depsc2 'bondprice1.eps'

figure
fill([2 2 3 3]',[0 105 105 0],'y');
hold on
plot((1:T1)/12,100*exp(p(1:T1)),'-v','markersize',2,'linewidth',2)
%plot((T1:T)/12,100*exp(p(T1:T)),'-','markersize',2)
plot((T1:T)/12,100*exp(p_extra(T1:T,[1 3 4])),'-','markersize',2)
plot(10,100,'v','markersize',5,'markerfacecolor','b')
axis([0 10.1 0 105])
%plot((1:T)/12,1000*r,'-r')
xlabel('time, years')
ylabel('bond price')
title('Price of a bond that matures in year 10 -- simulation')
print -depsc2 'bondprice2.eps'

Ts = [26 29 32 T1]';
lines1 = (p(Ts(1)):-p(Ts(1))/(T-Ts(1)):0);
Tlines1 = (Ts(1):T);

lines2 = (p(Ts(2)):-p(Ts(2))/(T-Ts(2)):0);
Tlines2 = (Ts(2):T);

lines3 = (p(Ts(3)):-p(Ts(3))/(T-Ts(3)):0);
Tlines3 = (Ts(3):T);

lines4 = (p(Ts(4)):-p(Ts(4))/(T-Ts(4)):0);
Tlines4 = (Ts(4):T);


figure
fill([2 2 3 3]',[0 105 105 0],'y');
hold on
plot((1:T1)/12,100*exp(p(1:T1)),'-v','markersize',2,'linewidth',2)
%plot((T1:T)/12,100*exp(p(T1:T)),'-','markersize',2)
plot((T1:T)/12,100*exp(p_extra(T1:T,1)),'-','markersize',2)
plot(Tlines1/12,100*exp(lines1),'--r','linewidth',2);
plot(Tlines2/12,100*exp(lines2),'--r','linewidth',2);
plot(Tlines3/12,100*exp(lines3),'--r','linewidth',2);
plot(Tlines4/12,100*exp(lines4),'--r','linewidth',2);
%title('Price of a bond that matures in year 10 -- simulation')
plot(10,100,'v','markersize',5,'markerfacecolor','b')
axis([0 10.1 0 105])

%plot((1:T)/12,1000*r,'-r')
xlabel('Time')
ylabel('Bond price')
print -depsc2 'bondprice3.eps'
