
% analyze hedge fund index returns
% 
% Ideas: SET UP A SIMULATION to show that selection causes mean up, smoothness up,
% maybe less beta? Select on overall return also on one year declines, that
% should give smoothness
% see selbias_sim 

clear all;
close all; 
addpath('Data'); 
addpath('functions');
maxdate = 2012 ; % axis for graphs

data_source = 1; % 1 = cfsb; 2 = hfr. Using hfr will require some fixing
create_data = 1; % 1 to create factor data from underlying sources. 0 to load data from text file. 
graphs = 1; % 0 can speed up run by not making all the graphs

% ************
% Create data
% ************

 % new data from CFSB
 
 if data_source == 1;
    x = load('hedgeindexdotcom_data.csv');
    T = size(x,1);
    x = x(T:-1:1,:); % data is in reverse order 
    HFdates = x(:,1:3); 
    r = x(:,4:end-1);  % ignore multi-strategy rather than program up a separate sample period. 
    THF = size(x,1); 
    %mo,day,year,Hedge Fund Index,Hedge Fund Index Convertible Arbitrage,Hedge Fund Index Dedicated Short Bias,Hedge Fund Index Emerging Markets,Hedge Fund Index Equity Market Neutral,Hedge Fund Index Event Driven,Hedge Fund Index Distressed,Hedge Fund Index Multi-Strategy,Hedge Fund Index Risk Arbitrage,Hedge Fund Index Fixed Income Arbitrage,Hedge Fund Index Global Macro,Hedge Fund Index Long/Short Equity,Hedge Fund Index Managed Futures,Hedge Fund Index Multi-Strategy
    lbls = {'HFIndex','ConvArb','ShortBias','EmergMkt','EquitMktNeut','EventDriven','Distress','Multi-Strat','RiskArb','BondArb','GlobalMacro','LongShtEqty','MgdFuture'}; %Multi-Strategy
    %           1            2           3         4                5                6              7           8         9           10              11          12                13             14          
    plotdate = x(:,1)/12+x(:,3);   
    plotdate_nav = [plotdate(1)-1/12; plotdate]; %??
    subset = [1 2 3 4 5 6 7 8 9 10 11 12];
    allindx = 1; % column # of index.
    axis_st = 1993; % first date for axis of plots 
 end;
 
 
 if data_source == 2; 
    % new data from HFR
    x = load('hfri_historical_yn.txt');
    lbls = {'Distress/Restruct','Merger Arb','Equity Mkt Neutral','Quant Direction','Short',...
          'Emerg Mkts','Equity Hedge','Event-Driven','FOF Conservative','FOF Diversified','FOF Mkt Defensive',...
          'FOF Strategic','FOF Composite','HF Composite','Macro','Macro Syst. Divsfy',...
          'RV Total','RV Fixed & Conv Arb','RV Fixed Inc-Corp','RV Multi-Strat'} ;
    %    
    % lbls = {'Distressed/Restructuring','Merger Arbitrage','Equity Market Neutral','Quantitative Directional','Short Bias',...
    %                  1                       2                   3                           4                 5       
    %        'Emerging Markets','Equity Hedge','Event-Driven','FOF: Conservative','FOF: Diversified','FOF: Market Defensive',...
    %                    6               7            8                  9                   10               11                    
    %        'FOF: Strategic','Fund of Funds Composite','Fund Weighted Composite','Macro (Total)','Macro: Systematic Diversified',...
    %                   12                13                            14             15                      16
    %        'Relative Value (Total)','RV: Fixed Income-Convertible Arbitrage','RV: Fixed Income-Corporate','RV: Multi-Strategy'} ;
    %                   17                                18                              19                      20         
    subset = [14 2 3 4 6 13 15 19] ; % interesting ones for plotting

    THF = size(x,1); 
    r = x(:,3:end) ; % returns; cut off date field.
    plotdate = x(:,2)/12+x(:,1);   
    plotdate_nav = [plotdate(1)-1/12; plotdate]; %??
    allindx = 14; % index(column) of all funds index
    axis_st = 1989; % first date for axis of plots 
 end;
    
 nav = cumprod([100*ones(1,size(r,2)); 1+r/100]); 
 
 % form date vectors for x axis of plots over time

 % **************************
 % Factor data. Option 1, create from underlying files, use when updating
 % data
 % *************************
 
if create_data;
 
 x =  load('F-F_Research_Data_Factors_monthly.txt');
 if data_source == 1; 
    ff_start_date = 199401;
 end;
 if data_source == 2; 
    ff_start_date = 199001;    
 end;
 sti = find(x(:,1) == ff_start_date);
 ff_dates = x(sti:sti+THF-1,1);
 rmrf = x(sti:sti+THF-1,2); % allows for factors longer than returns
 smb = x(sti:sti+THF-1,3);
 hml = x(sti:sti+THF-1,4);
 rf = x(sti:sti+THF-1,5);
 rm = rmrf + rf; 

 x = load('F-F_Momentum_Factor_monthly.txt'); 
 sti = find(x(:,1) == ff_start_date);
 umd = x(sti:sti+THF-1,2); 
end  
   
 % ------------------
 % one year returns
 % ------------------
 
 if graphs; % comments out this section 
     
 % short sample plot of index to make hf look good
 shortsmp = find(plotdate<2008);
 figure;
 plot(plotdate(shortsmp),filter(ones(12,1),1,r(shortsmp,allindx)),'-r','linewidth',2);
 hold on
 plot(plotdate,0*plotdate,'-k'); 
 legend('HF',3 );
 axis([axis_st maxdate -40 40]); 
 title('Hedge Fund Index Annual Returns to 2008'); 
 print -depsc2 hedge_return_history_old.eps; 

 % longer sample to see risk 
 figure;
 plot(plotdate,filter(ones(12,1),1,r(:,allindx)),'-r','linewidth',2);
 hold on
 plot(plotdate,0*plotdate,'-k'); 
 legend('HF',3 );
 axis([axis_st maxdate -40 40]); 
 title('Hedge Fund Index Annual Returns'); 
 print -depsc2 hedge_return_history_a.eps; 



 % everyone with rmrf
 for i = 1:size(r,2); 
     figure
     plot(plotdate,100*(exp(filter(ones(12,1),1,log(1+r(:,i)/100)))-1),'-r','linewidth',2);
     hold on 
     plot(plotdate,100*(exp(filter(ones(12,1),1,log(1+rm(:,1)/100)))-1),'-b','linewidth',2);
     plot(plotdate,0*plotdate,'-k'); 
     legend('HF','rmrf',3 );
     axis([axis_st maxdate -50 60]); 
     title(char(lbls(i)')); 
     print('-depsc2',['one_yr_returns_' char(lbls(i)) '.eps' ])
 end;
 
 end; % ends if graphs to comment out this section. 
 
