% makes price rent ratio graph and regression

clear all
close all

addpath('data');   % I keep all my data in the same place, and then separate directories for each problem set; 
                      %  this lets matlab find data for load commands. Omit if you're keeping
                      %  data in the same directory as your program
addpath('functions');  % Again, I keep programs such as regress_jc all in the same place; omit if you keep them 
                         % in the current directory. 

x = load('GDPCTPI.txt');
gdpdeflator = x(54:end,4); 

x = load('price_rent.txt');
dates = x(:,1);
yr = floor(dates);
qtr = 10*(dates-yr);
rent = x(:,2)./gdpdeflator;
csprice = x(:,3)./gdpdeflator;
csrp = x(:,4);
ofheoprice = x(:,5)./gdpdeflator; 
ofheorp = x(:,6); 

figure
plot(datenum(yr,3*qtr,1),log([20*rent csprice ofheoprice]),'linewidth',2);
axis([datenum(1960,1,1),datenum(2011,1,1),-inf, inf])
text(datenum(1966,1,1),7,'20 x Rent','color','b');
text(datenum(1997,1,1),7.6,'Price','Color','r');
datetick('x','keeplimits')
legend('20 x rent','CSW price','OFHEO',2)
xlabel('Date')
ylabel('log scale');

print -depsc2 price_and_rent

figure; 
plot(datenum(yr,3*qtr,1),[csrp ofheorp],'linewidth',2);
datetick('x')
xlabel('Date')
ylabel('Rent-price ratio');
axis([-inf inf 0 7]); 
legend('CSW', 'OFHEO',3); 

arent = rent(1);% guess last year's rent the same as this value
arent = [arent; [rent(2:4:end)+rent(3:4:end)+rent(4:4:end)+rent(5:4:end)]/4]; %e.g. assign Q2+Q3+Q4+Q1 rent to next years Q1 price
acsprice = csprice(1:4:end); % price is the Q1 value
aofprice = ofheoprice(1:4:end);
acsrp = csrp(1:4:end);
aofrp = ofheorp(1:4:end);


T = size(arent,1);
dataset = 2; % 1 = case shiller 2: of
weights = 1; % rho weighted regressions as in volatility tests

if dataset == 1; 
    disp('CSW Data')
    price = acsprice;
    rp = acsrp;
elseif dataset == 2;
    disp('OFHEO Data'); 
    price = aofprice;
    rp = aofrp; 
end;

if weights; 
    rho = 0.95; % expansion point need not be mean pd; this is round and close 
    disp('using rho weights')
else;
    rho = 1; 
    disp('unweighted results')
end;


r = [NaN; log((price(2:T)+arent(2:T))./price(1:T-1))];
r5 = [NaN; NaN; NaN; NaN; NaN; r(2:T-4)+rho*r(3:T-3)+rho^2*r(4:T-2)+rho^3*r(5:T-1)+rho^4*r(6:T)];
R7 = [NaN; NaN; NaN; NaN; NaN;NaN;NaN; r(2:T-6)+rho*r(3:T-5)+rho^2*r(4:T-4)+rho^3*r(5:T-3)+rho^4*r(6:T-2)+rho^5*r(7:T-1)+rho^6*r(8:T)];

dp = [NaN; log(price(2:T)./price(1:T-1))];

dd = [NaN; log(arent(2:T)./arent(1:T-1))]; 
dd5 = [NaN; NaN; NaN; NaN; NaN; dd(2:T-4)+rho*dd(3:T-3)+rho^2*dd(4:T-2)+rho^3*dd(5:T-1)+rho^4*dd(6:T)];
dd7 = [NaN; NaN; NaN; NaN; NaN;NaN;NaN; dd(2:T-6)+rho*dd(3:T-5)+rho^2*dd(4:T-4)+rho^3*dd(5:T-3)+rho^4*dd(6:T-2)+rho^5*dd(7:T-1)+rho^6*dd(8:T)];

% first order VAR
rhv = [ones(T-1,1) log(rp(1:T-1))];
lhv = [r(2:T) dp(2:T) dd(2:T) log(rp(2:T))];
[bv,sebv,R2v,R2vadj,v,F] = olsgmm(lhv,rhv,0,0);
fprintf('first order VAR of price and rent\n'); 
fprintf('           %8.8s %8.8s %8.8s \n', 'b', 't', 'R2'); 
fprintf('Return     %8.2f %8.2f %8.2f \n', bv(2,1), bv(2,1)/sebv(2,1), R2v(1)); 
fprintf('Price ch   %8.2f %8.2f %8.2f \n', bv(2,2), bv(2,2)/sebv(2,2), R2v(2)); 
fprintf('Rent ch    %8.2f %8.2f %8.2f \n', bv(2,3), bv(2,3)/sebv(2,3), R2v(3)); 
fprintf('Rent/price %8.2f %8.2f %8.2f \n', bv(2,4), bv(2,4)/sebv(2,4), R2v(4));

br = bv(2,1);
bd = bv(2,3);
phi = bv(2,4); 


% direct and VAR
fprintf('Regressions of house returns and rent growth on rent-price ratio\n');
fprintf( '         %8.8s %8.8s %8.8s %8.8s %8.8s %8.8s %8.8s %8.8s %8.8s %8.8s %8.8s %8.8s \n',' ',' ','Return',' ',' ', ' ', 'Rent',' ',' ',' ', 'R/P',' ');  
fprintf( '         %8.8s %8.8s %8.8s %8.8s %8.8s %8.8s %8.8s %8.8s %8.8s %8.8s %8.8s %8.8s \n', 'var','b','t','R2','var','b','t','R2','var','b','t','R2');

rhv = [ones(T-1,1) log(rp(1:T-1))];
lhv = [r(2:T) dd(2:T) rho*log(rp(2:T))];
[bv,sebv,R2v,R2vadj,v,F] = olsgmm(lhv,rhv,0,0);
fprintf( ' 1 year  %8.2f %8.2f %8.2f %8.2f %8.2f %8.2f %8.2f %8.2f %8.2f %8.2f %8.2f %8.2f \n',  br, bv(2,1), bv(2,1)/sebv(2,1), R2v(1),...
                                                                               bd, bv(2,2), bv(2,2)/sebv(2,2), R2v(2),...
                                                                               phi, bv(2,3), bv(2,3)/sebv(2,3), R2v(3));

rhv = [ones(T-5,1) log(rp(1:T-5))];
lhv = [r(6:T) dd(6:T) rho^5*log(rp(6:T))];
[bv,sebv,R2v,R2vadj,v,F] = olsgmm(lhv,rhv,0,0);
fprintf( ' 5 year  %8.2f %8.2f %8.2f %8.2f %8.2f %8.2f %8.2f %8.2f %8.2f %8.2f %8.2f %8.2f \n', br*(1-rho^5*phi^5)/(1-rho*phi), bv(2,1), bv(2,1)/sebv(2,1), R2v(1),...
                                                                               bd*(1-rho^5*phi^5)/(1-rho*phi),bv(2,2), bv(2,2)/sebv(2,2), R2v(2),...
                                                                               rho^5*phi^5,bv(2,3), bv(2,3)/sebv(2,3), R2v(3));
                                                                         
rhv = [ones(T-7,1) log(rp(1:T-7))];
lhv = [r(8:T) dd(8:T) rho^7*log(rp(8:T))];
[bv,sebv,R2v,R2vadj,v,F] = olsgmm(lhv,rhv,0,0);
fprintf( ' 7 year  %8.2f %8.2f %8.2f %8.2f %8.2f %8.2f %8.2f %8.2f %8.2f %8.2f %8.2f %8.2f \n',  br*(1-rho^7*phi^5)/(1-rho*phi),bv(2,1), bv(2,1)/sebv(2,1), R2v(1),...
                                                                               bd*(1-rho^7*phi^7)/(1-rho*phi),bv(2,2), bv(2,2)/sebv(2,2), R2v(2),...
                                                                               rho^7*phi^7,bv(2,3), bv(2,3)/sebv(2,3), R2v(3));
                                                                           
fprintf( 'infinite %8.2f %8.2s %8.2s %8.2s %8.2f %8.2s %8.2s %8.2s %8.2f %8.2s %8.2s %8.2s\n',  br/(1-rho*phi),' ', ' ',' ',...
                                                                               bd/(1-rho*phi),' ', ' ',' ',...
                                                                               0,' ', ' ',' ');
% Lesson of the table. Price and rent seem not well described by the AR1
% structure. In this specification we seem not to have conefficients that
% climb with horizon, but with other specifications I did. Given the
% quality of the data, I abandoned all this and jsut reported one year
% regressoins. 



            